MLDSA87 class

Constructors

MLDSA87()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateKeyPair({Uint8List? coins}) → KeyPair
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(Uint8List privateKey, Uint8List message, {Uint8List? context, Uint8List? coins}) Uint8List
inherited
toString() String
A string representation of this object.
inherited
verify(Uint8List publicKey, Uint8List message, Uint8List signature, {Uint8List? context}) bool
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited